@@ -22,7 +22,7 @@ def hcl_to_json(file_path):
         except Exception as e:
             error = str(e)
             error = error.split("Expected one of")[0]
-            logger.error("Unspported terraform file, error while parsing file: %s , error: %s", file_path, error)
+            logger.debug("Unspported terraform file, error while parsing file: %s , error: %s", file_path, error)
 
     return json_data
 
